==> haskell-storable-complex-0.2.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.2
id: storable-complex-0.2.2-FSABE3feilmDkeXwFQmko6
key: storable-complex-0.2.2-FSABE3feilmDkeXwFQmko6
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: 84f8112bf3cf6b5fcc8d95820d77bf33
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.4.3/site-local/storable-complex-0.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/storable-complex-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/storable-complex-0.2.2
hs-libraries: HSstorable-complex-0.2.2-FSABE3feilmDkeXwFQmko6
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.3.0
id: storable-complex-0.2.3.0-5xTAFtkepj3KUIZMH9UiwE
key: storable-complex-0.2.3.0-5xTAFtkepj3KUIZMH9UiwE
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: e4d4e106d0b36fb84ba15c9e5652841e
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.6.1/site-local/storable-complex-0.2.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/storable-complex-0.2.3.0
hs-libraries: HSstorable-complex-0.2.3.0-5xTAFtkepj3KUIZMH9UiwE
depends:
    base-4.12.0.0 base-orphans-0.8-MvDA9MxK5e7YBvQaNB0jM
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
